@@ -1153,7 +1153,7 @@ void updateinstparam(objectptr bobj, int mode)
       for (j = 0; j < pageobj->parts; j++)
 	 if (*(pageobj->plist + j) == (genericptr)pinst) break;
       if (j == pageobj->parts) {
-	 fprintf(stderr, "Error: Calling page does not contain expected objinst!\n");
+	 Fprintf(stderr, "Error: Calling page does not contain expected objinst!\n");
 	 return;
       }
       calcbboxvalues(pinst, (genericptr *)(pageobj->plist + j));
@@ -1166,7 +1166,7 @@ void updateinstparam(objectptr bobj, int mode)
 	 }
       }
       if (i == xobjs.pages)
-	 fprintf(stderr, "Error: Calling page not found!\n");
+	 Fprintf(stderr, "Error: Calling page not found!\n");
    }
 
    /* mode == 1:  change bounds on pagelib and all pages	*/
@@ -1408,7 +1408,17 @@ void UDrawLine(XPoint *pt1, XPoint *pt2)
 } 
 
 /*----------------------------------------------------------------------*/
-/* Add circle at given point						*/
+/* Add circle at given point to indicate that the point is a parameter.	*/
+/* The circle is divided into quarters.  For parameterized y-coordinate	*/
+/* the top and bottom quarters are drawn.  For parameterized x-		*/
+/* coordinate, the left and right quarters are drawn.  A full circle	*/
+/* indicates either both x- and y-coordinates are parameterized, or	*/
+/* else any other kind of parameterization (presently, not used).	*/
+/*									*/
+/* (note that the two angles in XDrawArc() are 1) the start angle,	*/
+/* measured in absolute 64th degrees from 0 (3 o'clock), and 2) the	*/
+/* path length, in relative 64th degrees (positive = counterclockwise,	*/
+/* negative = clockwise)).						*/
 /*----------------------------------------------------------------------*/
 
 void UDrawCircle(XPoint *upt, u_char which)
@@ -1417,25 +1427,23 @@ void UDrawCircle(XPoint *upt, u_char which)
 
    user_to_window(*upt, &wpt);
    XSetLineAttributes(dpy, areastruct.gc, 0, LineSolid, CapButt, JoinMiter);
+
    switch(which) {
       case P_POSITION_X:
-	 fprintf(stderr, "Draw circle X at %d, %d\n", wpt.x, wpt.y);
-         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 3,
-		wpt.y - 3, 6, 6, -45, 45);
-         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 3,
-		wpt.y - 3, 6, 6, 135, 225);
+         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 4,
+		wpt.y - 4, 8, 8, -(45 * 64), (90 * 64));
+         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 4,
+		wpt.y - 4, 8, 8, (135 * 64), (90 * 64));
 	 break;
       case P_POSITION_Y:
-	 fprintf(stderr, "Draw circle Y at %d, %d\n", wpt.x, wpt.y);
-         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 3,
-		wpt.y - 3, 6, 6, 45, 135);
-         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 3,
-		wpt.y - 3, 6, 6, 225, 315);
+         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 4,
+		wpt.y - 4, 8, 8, (45 * 64), (90 * 64));
+         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 4,
+		wpt.y - 4, 8, 8, (225 * 64), (90 * 64));
 	 break;
       default:
-	 fprintf(stderr, "Draw whole circle at %d, %d\n", wpt.x, wpt.y);
-         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 3,
-		wpt.y - 3, 6, 6, 0, 360);
+         XDrawArc(dpy, areastruct.areawin, areastruct.gc, wpt.x - 4,
+		wpt.y - 4, 8, 8, 0, (360 * 64));
 	 break;
    }
 }
