@@ -110,6 +110,8 @@ void dotoolbar(xcWidget w, caddr_t clientdata, caddr_t calldata)
 #endif
 }  
 
+#ifndef TCL_WRAPPER
+
 /*--------------------------------------------------------------*/
 /* Overwrite the toolbar pixmap for color or stipple entries	*/
 /*--------------------------------------------------------------*/
@@ -123,7 +125,6 @@ void overdrawpixmap(xcWidget button)
 
    if (button == NULL) return;
 
-#ifndef TCL_WRAPPER
    XtSetArg(args[0], XtNlabelType, &ltype);
    XtGetValues(button, args, 1);
 
@@ -157,10 +158,12 @@ void overdrawpixmap(xcWidget button)
 
       XtSetValues(pbutton, args, 2);
    }
-#endif
 }
 #else
 #define overdrawpixmap(a)
+#endif  /* TCL */
+#else
+#define overdrawpixmap(a)
 #endif	/* XPM */
 
 /*--------------------------------------------------------------*/
@@ -1008,12 +1011,14 @@ void setpagelabel(xcWidget w, char *dataptr)
 
 /*--------------------------------------------------------------*/
 /* Add a new font name to the list of known fonts		*/
+/* Register the font number for the Alt-F cycling mechanism	*/
+/* Tcl: depends on command tag mechanism for GUI menu update.	*/
 /*--------------------------------------------------------------*/
 
-#ifndef TCL_WRAPPER
-
 void makenewfontbutton()
 {
+
+#ifndef TCL_WRAPPER
    Arg	wargs[1];
    int  n = 0;
    xcWidget newbutton, cascade;
@@ -1028,6 +1033,7 @@ void makenewfontbutton()
    XtAddCallback (newbutton, XtNselect, (XtCallbackProc)setfont,
 		Number(fontcount - 1));
    XtManageChild(newbutton);
+#endif
 
    nfontnumbers++;
    if (nfontnumbers == 1)
@@ -1038,6 +1044,8 @@ void makenewfontbutton()
    fontnumbers[nfontnumbers - 1] = fontcount - 1;
 }
 
+#ifndef TCL_WRAPPER
+
 /*--------------------------------------------------------------*/
 /* Make new encoding menu button				*/
 /*--------------------------------------------------------------*/
@@ -1246,11 +1254,15 @@ void inversecolor(xcWidget w, Boolean *boolvalue, caddr_t calldata)
 void togglegrid(u_short type)
 {
    static char *stylenames[] = {
-      "\"decimal inches\"",
-      "\"fractional inches\"",
-      "\"centimeters\"",
+      "decimal inches",
+      "fractional inches",
+      "centimeters",
    };
 
+   /* Note that Tcl_SetVar() doesn't require double-quotes around the	*/
+   /* string; doing so prevents the menu from recognizing the variable	*/
+   /* value.								*/
+
    Tcl_SetVar(xcinterp, "gridstyle", stylenames[type], TCL_NAMESPACE_ONLY);
 }
 
@@ -1402,7 +1414,7 @@ int createlibrary()
 
 #ifdef TCL_WRAPPER
 
-   sprintf(_STR2, "newlibrarybutton \"%s\"", newlibobj->name);
+   sprintf(_STR2, "xcircuit::newlibrarybutton \"%s\"", newlibobj->name);
    Tcl_Eval(xcinterp, _STR2);
 
 #else
@@ -1490,12 +1502,16 @@ void makepagebutton()
 void renamepage(short pagenumber)
 {
 #ifdef TCL_WRAPPER
-   if ((pagenumber > 0) && (pagenumber < xobjs.pages) &&
+   char *pname, *plabel;
+
+   if ((pagenumber >= 0) && (pagenumber < xobjs.pages - 1) &&
 	    (xobjs.pagelist[pagenumber]->pageinst != NULL)) {
-      sprintf(_STR2, "renamepage %d \"%s\"", pagenumber + 1, 
-		xobjs.pagelist[pagenumber]->pageinst->thisobject->name);
+      plabel = xobjs.pagelist[pagenumber]->pageinst->thisobject->name;
+      pname = (char *)malloc(28 + strlen(plabel));
+      sprintf(pname, "xcircuit::renamepage %d {%s}", pagenumber + 1, plabel);
+      Tcl_Eval(xcinterp, pname);
+      free(pname);
    }
-   Tcl_Eval(xcinterp, _STR2);
 #else
    Arg wargs[1];
    xcWidget parent = XtParent(GotoPageAddNewPageButton);
@@ -1514,7 +1530,7 @@ void renamepage(short pagenumber)
       XtSetValues(button, wargs, 1);
    }
    else if (button == NULL)
-      printf("Error:  No Button xcWidget named \"%9s\"\n", bname);
+      Fprintf(stderr, "Error:  No Button Widget named \"%9s\"\n", bname);
 #endif
 }
 
@@ -1525,7 +1541,7 @@ void renamepage(short pagenumber)
 void renamelib(short libnumber)
 {
 #ifdef TCL_WRAPPER
-   sprintf(_STR2, "renamelib %d \"%s\"", libnumber - LIBRARY + 1,
+   sprintf(_STR2, "xcircuit::renamelib %d \"%s\"", libnumber - LIBRARY + 1,
 	xobjs.libtop[libnumber]->thisobject->name);
    Tcl_Eval(xcinterp, _STR2);
 #else
@@ -1545,7 +1561,7 @@ void renamelib(short libnumber)
       XtSetValues(button, wargs, 1);
    }
    else
-      printf("Error:  No Button xcWidget named \"%12s\"\n", bname);
+      Fprintf(stderr, "Error:  No Button Widget named \"%12s\"\n", bname);
 #endif
 }
 
@@ -1591,6 +1607,25 @@ void setcolormark(int colorval)
       XtSetArg(args[0], XtNsetMark, True);
       XtSetValues(w, args, 1);
    }
+#else
+   /* Set GUI variables and execute any command tags associated */
+   /* with the "color" command */
+
+   Tcl_Obj *objv[2];
+   int i;
+
+   objv[0] = Tcl_NewStringObj("color", 5);
+   if (colorval == DEFAULTCOLOR)
+      objv[1] = Tcl_NewStringObj("inherit", 7);
+   else {
+      for (i = 0; i < number_colors; i++)
+         if (colorlist[i].color.pixel == colorval)
+	    break;
+      objv[1] = Tcl_NewIntObj((int)i);
+   }
+   Tcl_SetVar2Ex(xcinterp, "colorval", NULL, objv[1], TCL_NAMESPACE_ONLY);
+
+   XcTagCallback(xcinterp, 2, objv);
 #endif
 }
 
@@ -1643,6 +1678,56 @@ void setallstylemarks(u_short styleval)
       }
    }
    toggleexcl(w, Stipples, XtNumber(Stipples));
+#else
+
+   /* Set GUI variables and execute any command tags associated	*/
+   /* with the "fill" and "border" commands.			*/
+
+   Tcl_Obj *objv[2];
+   int fillfactor;
+   const char *bptr;
+
+   const char *borders[] = {"solid", "unbordered", "dashed", "dotted"};
+   enum BorderIdx { SolidIdx, UnborderedIdx, DashedIdx, DottedIdx };
+
+   objv[0] = Tcl_NewStringObj("fill", 4);
+
+   if (styleval & FILLED) {
+      fillfactor = (int)(12.5 * (float)(1 + ((styleval & FILLSOLID) >> 5)));
+      if (fillfactor == 100)
+         objv[1] = Tcl_NewStringObj("solid", 5);
+      else
+         objv[1] = Tcl_NewIntObj(fillfactor);
+   }
+   else
+      objv[1] = Tcl_NewStringObj("unfilled", 8);
+
+   Tcl_SetVar2Ex(xcinterp, "fillamount", NULL, objv[1], TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "opaque", (styleval & OPAQUE) ? "true" : "false",
+		TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "bboxtype", (styleval & BBOX) ? "true" : "false",
+		TCL_NAMESPACE_ONLY);
+   Tcl_SetVar(xcinterp, "polyclosed", (styleval & UNCLOSED) ? "false" : "true",
+		TCL_NAMESPACE_ONLY);
+
+   switch (styleval & BORDERS) {
+      case DASHED:
+	 bptr = borders[DashedIdx];
+	 break;
+      case DOTTED:
+	 bptr = borders[DottedIdx];
+	 break;
+      case NOBORDER:
+	 bptr = borders[UnborderedIdx];
+	 break;
+      default:
+	 bptr = borders[SolidIdx];
+	 break;
+   }
+   Tcl_SetVar(xcinterp, "linestyle", (char *)bptr, TCL_NAMESPACE_ONLY);
+
+   XcTagCallback(xcinterp, 2, objv);
+
 #endif
 }
 
@@ -1790,7 +1875,7 @@ void setclosure(xcWidget w, pointertype value, caddr_t calldata)
 
 void setline(xcWidget w, pointertype value, caddr_t calldata)
 {
-   setelementstyle(w, (u_short)value, DASHED | DOTTED | NOBORDER);
+   setelementstyle(w, (u_short)value, BORDERS);
 }
 
 /*----------------------------------------------------------------*/
@@ -1874,7 +1959,7 @@ void setcolor(xcWidget w, pointertype value, caddr_t calldata)
       }
    }
 
-   setcolormark(cindex);
+   setcolormark(cval);
    if (!selected) {
       if (eventmode != TEXT2_MODE && eventmode != TEXT3_MODE)
          areastruct.color = cval;      
@@ -2100,6 +2185,7 @@ void startparam(xcWidget w, pointertype value, caddr_t calldata)
          settext = (genericptr *)EDITPART;
          makeparam(TOLABEL(settext));
          objectdeselect();
+	 setparammarks(NULL);
       }
       else if (checkselect(LABEL)) parameterize((int)value);
       else
@@ -2130,6 +2216,7 @@ void startunparam(xcWidget w, pointertype value, caddr_t calldata)
    else
       unparameterize((int)value);
    objectdeselect();
+   setparammarks(NULL);
 }
 
 /*----------------------------------------------------------------*/
