@@ -6,9 +6,12 @@
 /* from tclxcircuit.c */
 
 #ifdef TCL_WRAPPER
+
 extern Tk_EventProc *xctk_drag(ClientData, XEvent *);
 extern Tk_EventProc *xctk_draglscroll(ClientData, XEvent *);
 extern Tk_EventProc *xctk_dragfilebox(ClientData, XEvent *);
+extern int XcTagCallback(Tcl_Interp *, int, Tcl_Obj *CONST objv[]);
+
 #endif
 
 /* from elements.c: */
@@ -97,6 +100,7 @@ extern void printpos(short, short);
 extern void findwirex(XPoint *, XPoint *, XPoint *, XPoint *, int *);
 extern void findattach(XPoint *, int *, XPoint *);
 extern XPoint *pathclosepoint(pathptr, XPoint *);
+extern void placeselects(short, short, XPoint *);
 extern void drag(xcWidget, caddr_t, XButtonEvent *);
 extern void rotatebutton(XButtonEvent *);
 extern void elemrotate(genericptr *, short);
@@ -219,7 +223,7 @@ extern void printobjects(FILE *, objectptr, float, float, float, short, short,
 /* from fontfile.c: */
 
 extern FILE *findfontfile(char *);
-extern void loadfontfile(char *);
+extern int loadfontfile(char *);
 
 /* from formats.c: */
 
@@ -494,6 +498,7 @@ extern int porttonet(objectptr, int);
 extern int pointtonet(objectptr, XPoint *);
 extern stringpart *nettopin(int, objectptr, char *);
 extern int pintonet(objectptr, objinstptr, labelptr);
+extern int nametonet(objectptr, objinstptr, char *);
 extern char *parseinfo(objectptr, CalllistPtr, char *, char *, Boolean);
 extern int writedevice(FILE *, char *, objectptr, CalllistPtr, char *);
 extern void writeflat(objectptr, CalllistPtr, char *, FILE *, char *);
@@ -588,7 +593,7 @@ extern int reset_gs();
 extern void callgennet(xcWidget, pointertype, caddr_t);
 extern void doxschema(xcWidget, pointertype, caddr_t);
 extern void startconnect(xcWidget, caddr_t, caddr_t);
-extern void connectivity(xcWidget, caddr_t, caddr_t);
+extern int connectivity(xcWidget, caddr_t, caddr_t);
 extern Boolean setobjecttype(objectptr);
 extern void pinconvert(labelptr, pointertype);
 extern void dopintype(xcWidget, pointertype, caddr_t);
@@ -602,7 +607,7 @@ extern void changeotherpins(labelptr, stringpart *);
 extern void swapschem(xcWidget, pointertype, caddr_t);
 extern void dobeforeswap(xcWidget, caddr_t, caddr_t);
 extern void schemdisassoc();
-extern void startschemassoc(xcWidget, caddr_t, caddr_t);
+extern void startschemassoc(xcWidget, pointertype, caddr_t);
 extern void schemassoc(objectptr, objectptr);
 
 /* from selection.c: */
