@@ -134,7 +134,7 @@ void ask_for_next()
    XSync(dpy, False);
    send_client(gvnext);
 #ifdef GS_DEBUG
-   printf("Xcircuit: Sent NEXT message to ghostscript\n");
+   Fprintf(stdout, "Xcircuit: Sent NEXT message to ghostscript\n");
 #endif
 }
 
@@ -153,7 +153,7 @@ void wait_for_page()
 	 if (event.xclient.message_type == gvpage) break;
          else if (event.xclient.message_type == gvdone) {
 #ifdef GS_DEBUG
-	    printf("Xcircuit: Received DONE message from ghostscript\n");
+	    Fprintf(stdout, "Xcircuit: Received DONE message from ghostscript\n");
 #endif
 	    /* Catastrophic error in ghostscript */
 	    return;
@@ -166,15 +166,15 @@ void wait_for_page()
 	    break;
 	 }
 	 else {
-	    fprintf(stderr, "state = %d, keycode = %d\n", keyevent->state,
+	    Fprintf(stderr, "state = %d, keycode = %d\n", keyevent->state,
 		keyevent->keycode);
-	    XtDispatchEvent(&event);
+	    xcDispatchEvent(&event);
 	 }
       }
-      else XtDispatchEvent(&event);	
+      else xcDispatchEvent(&event);	
    }
 #ifdef GS_DEBUG
-   printf("Xcircuit: Received PAGE message from ghostscript\n");
+   Fprintf(stdout, "Xcircuit: Received PAGE message from ghostscript\n");
 #endif
    mwin = event.xclient.data.l[0];
 }
@@ -191,13 +191,13 @@ void wait_for_done()
 	 if (event.xclient.message_type == gvdone) break;
 #ifdef GS_DEBUG
          else if (event.xclient.message_type == gvpage)
-	    printf("Xcircuit: Received PAGE message from ghostscript\n");
+	    Fprintf(stdout, "Xcircuit: Received PAGE message from ghostscript\n");
 #endif
       }
-      else XtDispatchEvent(&event);
+      else xcDispatchEvent(&event);
    }
 #ifdef GS_DEBUG
-   printf("Xcircuit: Received DONE message from ghostscript\n");
+   Fprintf(stdout, "Xcircuit: Received DONE message from ghostscript\n");
 #endif
    mwin = 0;
 }
@@ -234,7 +234,7 @@ void start_gs()
       gsproc = vfork();
       if (gsproc == 0) {		/* child process (gs) */
 #ifdef GS_DEBUG
-         printf("Calling %s\n", GS_EXEC);
+         Fprintf(stdout, "Calling %s\n", GS_EXEC);
 #endif
 	 close(std_out[0]);
 #ifndef GS_DEBUG
@@ -269,11 +269,11 @@ void start_gs()
 	 setenv("GHOSTVIEW", _STR, True);
 #endif
 #endif
-	 fprintf(stderr, "Did putenv \"%s\"\n", env_str2);
-	 fflush(stderr);
+	 Fprintf(stderr, "Did putenv \"%s\"\n", env_str2);
+	 Flush(stderr);
          execlp(GS_EXEC, "gs", "-dNOPAUSE", "-", NULL);
 	 gsproc = -1;
-	 printf("Exec of gs failed\n");
+	 Fprintf(stderr, "Exec of gs failed\n");
 	 return;
       }
       else if (gsproc < 0) {
@@ -310,14 +310,16 @@ void parse_bg(FILE *fi, FILE *fbg) {
 	       sscanf(bbptr + 12, "%d %d %d %d", &llx, &lly, &urx, &ury);
 	       /* compute user coordinate bounds from PostScript bounds */
 #ifdef GS_DEBUG
-	       printf("BBox %d %d %d %d PostScript coordinates\n", llx, lly, urx, ury);
+	       Fprintf(stdout, "BBox %d %d %d %d PostScript coordinates\n",
+			llx, lly, urx, ury);
 #endif
 	       llx = (int)((float)llx / psscale);
 	       lly = (int)((float)lly / psscale);
 	       urx = (int)((float)urx / psscale);
 	       ury = (int)((float)ury / psscale);
 #ifdef GS_DEBUG
-	       printf("BBox %d %d %d %d XCircuit coordinates\n", llx, lly, urx, ury);
+	       Fprintf(stdout, "BBox %d %d %d %d XCircuit coordinates\n",
+			llx, lly, urx, ury);
 #endif
 	
 	       xobjs.pagelist[areastruct.page]->background.bbox.lowerleft.x = llx;
@@ -343,7 +345,7 @@ void bg_get_bbox()
 
    fname = xobjs.pagelist[areastruct.page]->background.name;
    if ((fi = fopen(fname, "r")) == NULL) {
-      printf("Failure to open background file to get bounding box info\n");
+      Fprintf(stderr, "Failure to open background file to get bounding box info\n");
       return;
    }
    parse_bg(fi, (FILE *)NULL);
@@ -394,10 +396,10 @@ void readbackground(FILE *fi)
    sprintf(file_in, "@%s/XXXXXX", xobjs.tempdir);
 
    tfd = mkstemp(file_in + 1);
-   if (tfd == -1) printf("Error generating temporary filename\n");
+   if (tfd == -1) Fprintf(stderr, "Error generating temporary filename\n");
    else {
       if ((fbg = fdopen(tfd, "w")) == NULL) {
-	 printf("Error opening temporary file \"%s\"\n", file_in + 1);
+	 Fprintf(stderr, "Error opening temporary file \"%s\"\n", file_in + 1);
       }
    }
 
@@ -427,7 +429,7 @@ void savebackground(FILE *fo, char *psfilename)
    if (fname[0] == '@') fname++;
 
    if ((psf = fopen(fname, "r")) == NULL) {
-      printf("Error opening background file \"%s\" for reading.\n", fname);
+      Fprintf(stderr, "Error opening background file \"%s\" for reading.\n", fname);
       return;
    }
 
@@ -475,7 +477,7 @@ void send_to_gs(char *text)
 {
    write(fgs[1], text, strlen(text));
 #ifdef GS_DEBUG
-   printf("writing: %s", text);
+   Fprintf(stdout, "writing: %s", text);
 #endif
 }
 
@@ -517,7 +519,7 @@ int renderbackground()
    if (*bgfile == '@') bgfile++;
 
 #ifdef GS_DEBUG
-   printf("Rendering background from file \"%s\"\n", bgfile);
+   Fprintf(stdout, "Rendering background from file \"%s\"\n", bgfile);
 #endif
 
    /* write scale and position to ghostscript 		*/
@@ -581,11 +583,11 @@ int exit_gs()
    send_to_gs("quit\n");
    ask_for_next();
 #ifdef GS_DEBUG
-   printf("Waiting for gs to exit\n");
+   Fprintf(stdout, "Waiting for gs to exit\n");
 #endif
    waitpid(gsproc, NULL, 0);      
 #ifdef GS_DEBUG
-   printf("gs has exited\n");
+   Fprintf(stdout, "gs has exited\n");
 #endif
 
    mwin = 0;
