@@ -43,6 +43,10 @@
 /* External Variable definitions                                          */
 /*------------------------------------------------------------------------*/
 
+#ifdef TCL_WRAPPER
+extern Tcl_Interp *xcinterp;
+#endif
+
 extern Globaldata xobjs;
 extern Clientdata areastruct;
 extern short	  eventmode;
@@ -150,7 +154,7 @@ int checkpagename(objectptr thispageobj)
       }
    }
    if (p == xobjs.pages) {
-      fprintf(stderr, "Error:  Object is not a page object!\n");
+      Fprintf(stderr, "Error:  Object is not a page object!\n");
       return 0;
    }
 
@@ -196,15 +200,16 @@ void startconnect(xcWidget button, caddr_t clientdata, caddr_t calldata)
 }
 
 /*----------------------------------------------------------------------*/
-/* rconnectivity():  Find electrical connections into a node.		*/
+/* connectivity():  Find electrical connections into a node.		*/
 /* (does recursive search on object heirarchy)				*/
+/* Returns net number found (0 if no network found, -1 if error)	*/
 /*----------------------------------------------------------------------*/
 
-void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
+int connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
 {
    short *gsel;
    genericptr ggen;
-   int depth, netid;
+   int depth, netid = -1;
    pushlistptr seltop, nextptr;
    objectptr nettop, thisobj;
    char *snew;
@@ -250,9 +255,9 @@ void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
          createnets();
       }
       if ((netid = is_resolved(&ggen, seltop, &nettop)) != 0) {
-         /* printf("Net ID is %d in object %s\n", netid, nettop->name); */
+         /* Fprintf(stdout, "Net ID is %d in object %s\n", netid, nettop->name); */
          depth = pushnetwork(seltop, nettop);
-         /* printf(">> Pushed network %d levels deep\n", depth); */
+         /* Fprintf(stdout, ">> Pushed network %d levels deep\n", depth); */
          nextptr = seltop;
          while (nextptr->thisinst->thisobject != nettop)
 	    nextptr = nextptr->next;
@@ -270,15 +275,22 @@ void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
 
 	 ppin = nettopin(netid, nettop, NULL);
          snew = textprint(ppin, areastruct.topinstance);
+
 	 sprintf(_STR, "Network is \"%s\" in %s", snew, nettop->name);
 	 Wprintf(_STR);
+
+#ifdef TCL_WRAPPER
+	 Tcl_SetObjResult(xcinterp, Tcl_NewStringObj(snew, strlen(snew)));
+#endif
          free(snew);
       }
       else
 	 Wprintf("Selected element is not part of a valid network.");
    }
-   else 
+   else { 
       Wprintf("No networks found near the cursor position");
+      netid = 0;
+   }
 
    /* free up linked list */
 
@@ -287,6 +299,7 @@ void connectivity(xcWidget button, caddr_t clientdata, caddr_t calldata)
       free(seltop);
       seltop = nextptr;
    }
+   return netid;
 }
 
 /*--------------------------------------------------------------*/
@@ -304,14 +317,17 @@ Boolean setobjecttype(objectptr cschem)
 
    /* Apply only to schematic objects */
 
-   if (cschem->schemtype != SCHEMATIC && cschem->symschem == NULL) {
-      if (cschem->schemtype == FUNDAMENTAL) cschem->schemtype = SYMBOL;
-      for (cgen = cschem->plist; cgen < cschem->plist + cschem->parts; cgen++) {
-         if ((*cgen)->type == LABEL) {
-            clab = TOLABEL(cgen);
-	    if (clab->pin == INFO) {
-	       cschem->schemtype = FUNDAMENTAL;
-	       break;
+   if (cschem->schemtype != SCHEMATIC) {
+      if (cschem->schemtype == FUNDAMENTAL)
+	 cschem->schemtype = SYMBOL;
+      if (cschem->symschem == NULL) {
+         for (cgen = cschem->plist; cgen < cschem->plist + cschem->parts; cgen++) {
+            if ((*cgen)->type == LABEL) {
+               clab = TOLABEL(cgen);
+	       if (clab->pin == INFO) {
+	          cschem->schemtype = FUNDAMENTAL;
+	          break;
+	       }
 	    }
          }
       }
@@ -406,7 +422,14 @@ void dopintype(xcWidget w, pointertype mode, caddr_t calldata)
 
 void setsymschem()
 {
-   /* to be done! */
+   /* This is temporary (hopefully). . . Call the Tcl function	*/
+   /* "setsymschem" which had better be defined by the wrapper.	*/
+
+   Tcl_SavedResult state;
+
+   Tcl_SaveResult(xcinterp, &state);
+   Tcl_Eval(xcinterp, "xcircuit::setsymschem");
+   Tcl_RestoreResult(xcinterp, &state);
 }
 
 #else
@@ -523,7 +546,8 @@ int findsubschems(int toppage, objectptr cschem, int level)
 
 	 if (cobj->symschem != NULL) {
 	    int pageno = findpageobj(cobj->symschem);
-	    /* printf("Symbol %s has schematic at page %d\n", cobj->name, pageno); */
+	    /* Fprintf(stdout, "Symbol %s has schematic at page %d\n",
+			cobj->name, pageno); */
 	    if (pageno < 0) {	/* This shouldn't happen (hopefully) */
 	       Wprintf("Error: disconnected schematic!\n");
 	    }
@@ -539,7 +563,8 @@ int findsubschems(int toppage, objectptr cschem, int level)
 	    /* the schematic circuit!					 */
 	    
 	    if (cobj->symschem != cschem) {
-	       /* printf("Searching for dependencies of symbol %s\n", cobj->name); */
+	       /* Fprintf(stdout, "Searching for dependencies of symbol %s\n",
+			cobj->name); */
 	       if (findsubschems(toppage, cobj->symschem, level + 1) == -1)
 		  return -1;
 	    }
@@ -846,7 +871,7 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
 	       if (symlist != NULL) break;
 	    }
 	    if (p == xobjs.numlibs) {
-	       fprintf(stderr, "swapschem(): BAD SYMSCHEM\n");
+	       Fprintf(stderr, "swapschem(): BAD SYMSCHEM\n");
 	       return;
 	    }
          }
@@ -863,7 +888,6 @@ void swapschem(xcWidget w, pointertype mode, caddr_t calldata)
    setpage(TRUE);
    transferselects();
    refresh(NULL, NULL, NULL);
-
    setsymschem();
 }
 
@@ -927,14 +951,20 @@ void schemdisassoc()
 }
 
 /*--------------------------------------------------------------*/
-/* Schematic<-->symbol association.  Determine action from 	*/
-/* context (associate/disassociate, symbol or schematic)	*/
+/* Schematic<-->symbol association.  Determine whether action	*/
+/* acts on a symbol or a schematic from context.		*/
+/* mode == 0 associate only.					*/
+/* mode == 1 determine action (associate or disassociate) from 	*/
+/* context (toggle)						*/
 /*--------------------------------------------------------------*/
 
-void startschemassoc(xcWidget w, caddr_t clientdata, caddr_t calldata)
+void startschemassoc(xcWidget w, pointertype mode, caddr_t calldata)
 {
-   if (topobject->symschem != NULL)
+   if ((topobject->symschem != NULL) && (mode == 1))
       schemdisassoc();
+   else if ((topobject->symschem != NULL) && (mode == 0)) {
+      Wprintf("Refusing to undo current association.");
+   }
    else {
       eventmode = ASSOC_MODE;
       if (topobject->schemtype == SCHEMATIC) {
@@ -973,7 +1003,6 @@ void schemassoc(objectptr schemobj, objectptr symbolobj)
 
       /* Ensure that schematic (page) name is unique */
       while (checkpagename(schemobj) < 0);
-   
       setsymschem();	/* Set buttons and menu items appropriately */
    }
 }
