@@ -65,7 +65,9 @@ void selectfilter(xcWidget w, pointertype value, caddr_t calldata)
    else
       areastruct.filter |= bitwise;
 
+#ifndef TCL_WRAPPER
    toggle(w, &bval, calldata);
+#endif
 }
 
 /*----------------------------------------------------------------------------*/
@@ -149,9 +151,8 @@ void gendrawselected(short *newselect, objectptr curobj, objinstptr curinst)
    XSetForeground(dpy, areastruct.gc, SELECTCOLOR ^ BACKGROUND);
    geneasydraw(*newselect, DOFORALL, curobj, curinst);
 
-   /* XSetForeground(dpy, areastruct.gc, PARAMCOLOR ^ BACKGROUND); */
-   XSetFunction(dpy, areastruct.gc, GXcopy);
-   XSetForeground(dpy, areastruct.gc, PARAMCOLOR);
+/* XSetForeground(dpy, areastruct.gc, PARAMCOLOR ^ BACKGROUND); */
+   XSetForeground(dpy, areastruct.gc, AUXCOLOR ^ BACKGROUND);
    indicateparams(*(curobj->plist + *newselect));
 }
 
@@ -510,7 +511,7 @@ short *selectobject(short class, objectptr selobj, objinstptr selinst)
 	       XNextEvent(dpy, &event); 
 	       if (event.type != ButtonPress && event.type != ButtonRelease
 		    && event.type != MotionNotify && event.type != KeyPress)
-	          XtDispatchEvent(&event);
+	          xcDispatchEvent(&event);
 	       else if (event.type == ButtonPress) break;
 	    }
 	    if (buttonevent->button == Button3) {
@@ -540,7 +541,7 @@ short *selectobject(short class, objectptr selobj, objinstptr selinst)
 	 XNextEvent(dpy, &event); 
 	 if (event.type != ButtonPress && event.type != ButtonRelease &&
 		event.type != MotionNotify && event.type != KeyPress)
-	    XtDispatchEvent(&event);
+	    xcDispatchEvent(&event);
 	 else if ((event.type == ButtonPress) && (eventmode == PRESS_MODE))
 	    break;
 	 else if ((event.type == ButtonRelease) && (eventmode != PRESS_MODE))
@@ -905,7 +906,7 @@ genericptr recurselect(short class, pushlistptr *seltop)
    XPoint savesave, tmppt;
 
    if (*seltop == NULL) {
-      fprintf(stderr, "Error: recurselect called with NULL pushlist pointer\n");
+      Fprintf(stderr, "Error: recurselect called with NULL pushlist pointer\n");
       return NULL;
    }
 
@@ -914,8 +915,8 @@ genericptr recurselect(short class, pushlistptr *seltop)
 
    if ((selectobj = selectobject(class, selobj, selinst)) != NULL) {
       rgen = *(selobj->plist + (*selectobj));
-      /* printf("%s found in object %s\n", (rgen->type == LABEL) ? "label" : "polygon",
-			selobj->name); */
+      /* Fprintf(stdout, "%s found in object %s\n", (rgen->type == LABEL) ?
+			"label" : "polygon", selobj->name); */
       drawselects(selobj, selinst);
       clearselects();
    }
@@ -938,9 +939,10 @@ genericptr recurselect(short class, pushlistptr *seltop)
 		selinst->scale, selinst->rotation);
       areastruct.save.x = tmppt.x;
       areastruct.save.y = tmppt.y;
-      /* printf("objinst %s found in object %s; searching recursively\n",
+      /* Fprintf(stdout, "objinst %s found in object %s; searching recursively\n",
 		selinst->thisobject->name, selobj->name); */
-      /* printf("cursor position originally (%d, %d); in new object is (%d, %d)\n",
+      /* Fprintf(stdout, "cursor position originally (%d, %d); "
+		"in new object is (%d, %d)\n",
 		savesave.x, savesave.y,
 		areastruct.save.x, areastruct.save.y); */
       UPushCTM();
@@ -951,7 +953,7 @@ genericptr recurselect(short class, pushlistptr *seltop)
       areastruct.save.y = savesave.y;
    }
    /* else
-      printf("nothing found in object %s\n", selobj->name); */
+      Fprintf(stdout, "nothing found in object %s\n", selobj->name); */
 
    return rgen;
 }
