@@ -14,6 +14,19 @@ typedef unsigned int	u_int;
 typedef unsigned long	u_long;
 #endif
 
+/*----------------------------------------------------------------------*/
+/* Redefinition of fprintf() allows redirection of output to a console	*/
+/* in the Tcl interpreter-based version.				*/
+/*----------------------------------------------------------------------*/
+
+#ifdef TCL_WRAPPER
+  #define Fprintf tcl_printf
+  #define Flush tcl_stdflush
+#else
+  #define Fprintf fprintf
+  #define Flush fflush
+#endif
+
 /*----------------------------------------------------------------------*/
 /* Definition shortcuts 						*/
 /*----------------------------------------------------------------------*/
@@ -787,6 +800,7 @@ typedef struct _alias {
 #define xcIsRealized			Tk_IsMapped  /* not sure this is right */
 #define xcScreen			Tk_Screen
 #define xcParent			Tk_Parent
+#define xcDispatchEvent(a)		Tk_HandleEvent(a)
 #define xcAddTimeOut(a, b, c, d)	Tcl_CreateTimerHandler(b, c, d)
 #define xcRemoveTimeOut			Tcl_DeleteTimerHandler
 #define xcTimeOutProc			Tcl_TimerProc *
@@ -803,6 +817,7 @@ typedef struct _alias {
 #define xcIsRealized			XtIsRealized
 #define xcScreen			XtScreen
 #define xcParent			XtParent
+#define xcDispatchEvent(a)		XtDispatchEvent(a)
 #define xcAddTimeOut			XtAppAddTimeOut
 #define xcRemoveTimeOut			XtRemoveTimeOut
 #define xcTimeOutProc			XtTimerCallbackProc
